Object Utilities - kombu.abstract — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# Object Utilities - kombu.abstract

class `kombu.abstract.` `MaybeChannelBound`(*args, **kwargs)

  Mixin for classes that can be bound to an AMQP channel.

  `bind`(channel)

    Create copy of the instance that is bound to a channel.

  `channel`
  `is_bound`

    Returns `True` if the entity is bound.

  `maybe_bind`(channel)

    Bind instance to channel if not already bound.

  `when_bound`()

    Callback called when the class is bound.

class `kombu.abstract.` `Object`(*args, **kwargs)

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »